import {
  select, 
  json, 
  geoPath,
  geoCentroid,
  geoAlbersUsa,
  zoom,
  event,
  scaleSqrt,
  max,
} from 'd3';

import { feature, merge } from 'topojson';
import { loadAndProcessData } from './loadAndProcessData';
import { usMap } from './usMap';
import { timeSlider } from './timeSlider';

const svg = select('svg');
const usMapg = svg.append('g');
const timeSliderG = svg.append('g');

const width = +svg.attr('width');
const height = +svg.attr('height');


let data;
let date;
let dates;
let sizeScale = null;
let selection;
let selectedYear = 0; 
let csvData;
let usedDate = 1;


const setSelectedYear = thisDate => {
  usedDate = thisDate;
  //console.log(usedDate)
  render();
}; 
const stateMap = geoAlbersUsa();
const pathGenerator = map => geoPath().projection(map);
const radiusValue = d => d.properties['TotalVolume'];

loadAndProcessData().then(props => {
  data = props[0];
  dates = props[1];
  csvData = props[2];
  sizeScale = scaleSqrt()
    .domain([0, 100000])
    .range([0, 4]);
  
  render();
});
  

const render = () => { 
  usMapg.call(usMap,{
    pathGenerator,
    stateMap,
    data,
    sizeScale,
    radiusValue,
    svg,
    dates,
    csvData,
    usedDate
  });

    
  timeSliderG.call(timeSlider, {
    title: 'Select Week of 2017',
    xValue: d => d,
    xAxisLabel: 'Time',
    margin: {
      top: 520,
      right: 105,
      bottom: 10,
      left: 105
    },
    width,
    height,
    dates,
    selectedYear,
    setSelectedYear,
    usedDate
  });

 
};     

svg.append("g")
  .attr("class","slider")
  .selectAll('rect').data([null])
  .enter().append('rect')
  .attr('x',105)
  .attr('y',520)
  .attr('width',width-105-105)
  .attr('height',height-490-40)
  .attr('fill','none')
  .attr('stroke','black')
  .attr('stroke-width','3')


